package ${basePackage}.system;

import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.junit4.SpringRunner;
import org.springframework.transaction.annotation.Transactional;
import ${basePackage}.frame.base.Token;
import ${basePackage}.module.system.mgr.RoleResourceManager;
import ${basePackage}.module.system.req.*;
import ${basePackage}.module.system.rsp.*;

import static org.junit.Assert.assertTrue;


/**
 * RoleResourceTest -  - 角色资源关系测试用例
 *
 * @author wangbing
 * @version 0.0.1
 * @since 2019-12-27
 */
@RunWith(SpringRunner.class)
@SpringBootTest
@Transactional
public class RoleResourceTest {

    @Autowired
    private Token token;

    @Autowired
    private RoleResourceManager roleResourceManager;

    @Test
    public void testCreate() {
        RoleResourceCreateRequest request = new RoleResourceCreateRequest();
        request.setRoleId(1L);
        request.setResourceId(1L);

        RoleResourceCreateResponse response = roleResourceManager.create(request,token);

        assertTrue(!response.hasError());
    }

    @Test
    public void testDelete() {

        //创建数据
        RoleResourceCreateRequest createRequest = new RoleResourceCreateRequest();
        createRequest.setRoleId(1L);
        createRequest.setResourceId(1L);

        RoleResourceCreateResponse createResponse = roleResourceManager.create(createRequest,token);

        assertTrue(!createResponse.hasError() && createResponse.getId() > 0);
        //删除数据
        RoleResourceDeleteRequest request = new RoleResourceDeleteRequest();
        request.setId(createResponse.getId());

        RoleResourceDeleteResponse response = roleResourceManager.delete(request,token);

        assertTrue(!response.hasError() && response.getResult() == 1L);
    }

    @Test
    public void testUpdate() {
        //创建数据
        RoleResourceCreateRequest createRequest = new RoleResourceCreateRequest();
        createRequest.setRoleId(1L);
        createRequest.setResourceId(1L);

        RoleResourceCreateResponse createResponse = roleResourceManager.create(createRequest, token);

        assertTrue(!createResponse.hasError());

        //更新数据
        RoleResourceUpdateRequest request = new RoleResourceUpdateRequest();
        request.setId(createResponse.getId());
        request.setRoleId(1L);
        request.setResourceId(1L);

        RoleResourceUpdateResponse response = roleResourceManager.update(request,token);

        assertTrue(!response.hasError() && response.getResult() == 1L);
    }

    @Test
    public void testFind() {
        RoleResourceFindRequest request = new RoleResourceFindRequest();
        request.setRoleId(1L);
        request.setResourceId(1L);

        RoleResourceFindResponse response = roleResourceManager.find(request,token);

        assertTrue(!response.hasError());
    }

    @Test
    public void testGet() {
        //创建数据
        RoleResourceCreateRequest createRequest = new RoleResourceCreateRequest();
        createRequest.setRoleId(1L);
        createRequest.setResourceId(1L);

        RoleResourceCreateResponse createResponse = roleResourceManager.create(createRequest, token);

        assertTrue(!createResponse.hasError());

        //获得数据
        RoleResourceGetRequest request = new RoleResourceGetRequest();
        request.setId(createResponse.getId());

        RoleResourceGetResponse response = roleResourceManager.get(request,token);

        assertTrue(!response.hasError() && response.getRoleResource() != null);
    }
}
