package ${basePackage}.system;

import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.junit4.SpringRunner;
import org.springframework.transaction.annotation.Transactional;
import ${basePackage}.frame.base.Token;
import ${basePackage}.module.system.mgr.UserManager;
import ${basePackage}.module.system.req.*;
import ${basePackage}.module.system.rsp.*;

import static org.junit.Assert.assertTrue;


/**
 * UserTest -  - 用户测试用例
 *
 * @author wangbing
 * @version 0.0.1
 * @since 2019-12-27
 */
@RunWith(SpringRunner.class)
@SpringBootTest
@Transactional
public class UserTest {

    @Autowired
    private Token token;

    @Autowired
    private UserManager userManager;

    @Test
    public void testCreate() {
        UserCreateRequest request = new UserCreateRequest();
        request.setUserName("用户账户");
        request.setUserCode("用户代码");
        request.setUserAlias("用户别名");
        request.setUserPwd("用户密码");
        request.setUserStatus("code");
        request.setDeptId(1L);
        request.setDeptCode("部门代码");
        request.setDeptName("部门名称");

        UserCreateResponse response = userManager.create(request,token);

        assertTrue(!response.hasError());
    }

    @Test
    public void testDelete() {

        //创建数据
        UserCreateRequest createRequest = new UserCreateRequest();
        createRequest.setUserName("用户账户");
        createRequest.setUserCode("用户代码");
        createRequest.setUserAlias("用户别名");
        createRequest.setUserPwd("用户密码");
        createRequest.setUserStatus("code");
        createRequest.setDeptId(1L);
        createRequest.setDeptCode("部门代码");
        createRequest.setDeptName("部门名称");

        UserCreateResponse createResponse = userManager.create(createRequest,token);

        assertTrue(!createResponse.hasError() && createResponse.getId() > 0);
        //删除数据
        UserDeleteRequest request = new UserDeleteRequest();
        request.setId(createResponse.getId());

        UserDeleteResponse response = userManager.delete(request,token);

        assertTrue(!response.hasError() && response.getResult() == 1L);
    }

    @Test
    public void testUpdate() {
        //创建数据
        UserCreateRequest createRequest = new UserCreateRequest();
        createRequest.setUserName("用户账户");
        createRequest.setUserCode("用户代码");
        createRequest.setUserAlias("用户别名");
        createRequest.setUserPwd("用户密码");
        createRequest.setUserStatus("code");
        createRequest.setDeptId(1L);
        createRequest.setDeptCode("部门代码");
        createRequest.setDeptName("部门名称");

        UserCreateResponse createResponse = userManager.create(createRequest, token);

        assertTrue(!createResponse.hasError());

        //更新数据
        UserUpdateRequest request = new UserUpdateRequest();
        request.setId(createResponse.getId());
        request.setUserName("用户账户");
        request.setUserCode("用户代码");
        request.setUserAlias("用户别名");
        request.setUserPwd("用户密码");
        request.setUserStatus("code");
        request.setDeptId(1L);
        request.setDeptCode("部门代码");
        request.setDeptName("部门名称");

        UserUpdateResponse response = userManager.update(request,token);

        assertTrue(!response.hasError() && response.getResult() == 1L);
    }

    @Test
    public void testFind() {
        UserFindRequest request = new UserFindRequest();
        request.setUserName("用户账户");
        request.setUserCode("用户代码");
        request.setUserAlias("用户别名");
        request.setUserStatus("code");
        request.setDeptId(1L);
        request.setDeptCode("部门代码");
        request.setDeptName("部门名称");

        UserFindResponse response = userManager.find(request,token);

        assertTrue(!response.hasError());
    }

    @Test
    public void testGet() {
        //创建数据
        UserCreateRequest createRequest = new UserCreateRequest();
        createRequest.setUserName("用户账户");
        createRequest.setUserCode("用户代码");
        createRequest.setUserAlias("用户别名");
        createRequest.setUserPwd("用户密码");
        createRequest.setUserStatus("code");
        createRequest.setDeptId(1L);
        createRequest.setDeptCode("部门代码");
        createRequest.setDeptName("部门名称");

        UserCreateResponse createResponse = userManager.create(createRequest, token);

        assertTrue(!createResponse.hasError());

        //获得数据
        UserGetRequest request = new UserGetRequest();
        request.setId(createResponse.getId());

        UserGetResponse response = userManager.get(request,token);

        assertTrue(!response.hasError() && response.getUser() != null);
    }
}
